@@ -124,6 +124,10 @@ rtmvnorm <- function(mean, sigma, blc=NULL, lower,
     stop("init must have the same number of rows as lower and upper");
   }
   
-  rtmvnormcpp(mean, sigma, blc, lower, upper, init, burn);
+  x = rtmvnormcpp(mean, sigma, blc, lower, upper, init, burn);
+  if (p==1) {
+    x = as.vector(x);
+  }
+  x
 }
 
